@@ -1,7 +1,7 @@
 package MyAssociations::Feature;
 use Mojo::Base 'Mojolicious::Controller';
 
-sub list_user_features {
+sub list_user_feature {
     my $self = shift;
     $self->render( json => { data => [ { id => 1, name => 'mysql' }, { id => 2, name => 'mails' } ] } );
 }
@@ -13,16 +13,19 @@ sub create_user_feature {
 
 sub read_user_feature {
     my $self = shift;
-    $self->render( json => { data => { id => $self->stash('userId'), features => [ { id => 'mysql' }, { id => 'mails' } ] } } );
+    $self->render(
+        json => { data => { id => $self->stash('userId'), features => [ { id => 'mysql' }, { id => 'mails' } ] } } );
 }
 
 sub update_user_feature {
     my $self = shift;
-    $self->render( json => { data => { id => $self->stash('userId'), feature => { id => $self->stash('featureId') } } } );
+    $self->render(
+        json => { data => { id => $self->stash('userId'), feature => { id => $self->stash('featureId') } } } );
 }
 
 sub delete_user_feature {
     my $self = shift;
-    $self->render( json => { data => { id => $self->stash('userId'), feature => { id => $self->stash('featureId') } } } );
+    $self->render(
+        json => { data => { id => $self->stash('userId'), feature => { id => $self->stash('featureId') } } } );
 }
 1;
